@@ -1,6 +1,6 @@
 # -*- Mode: python; coding: utf-8; tab-width: 4; indent-tabs-mode: nil; -*-
 #
-# Copyright (C) 2015 - 2018 David Mohammed <fossfreedom@ubuntu.com>
+# Copyright (C) 2015 - 2019 David Mohammed <fossfreedom@ubuntu.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -191,6 +191,21 @@ class AltToolbarBase(GObject.Object):
         self.startup_completed = True
         self.reset_categories_pos(self.shell.props.selected_page)
         self.reset_toolbar(self.shell.props.selected_page)
+        # lets hide the ghastly floating bar in RB 3.4.3
+        cssdata = """
+        .floating-bar {
+            opacity: 0;
+        }
+        """
+        cssprovider = Gtk.CssProvider.new()
+        cssprovider.load_from_data(cssdata.encode())
+        screen = Gdk.Screen.get_default()
+        styleContext = Gtk.StyleContext()
+        styleContext.add_provider_for_screen(
+            self.shell.props.window.props.screen,
+            cssprovider,
+            Gtk.STYLE_PROVIDER_PRIORITY_USER,
+        )
         self.reset_entryview(self.shell.props.selected_page)
 
         if self.plugin.prefer_dark_theme:
@@ -305,6 +320,15 @@ class AltToolbarBase(GObject.Object):
             print("no page")
             return
 
+        # workaround for GTK Crashing issues due to the user locale
+        # non english locales (german for example) cause RB to
+        # seg fault when moving columns - sadly need to disable
+        # column moving capability for non-english locale users :(
+
+        names = GLib.get_language_names()
+        if ("en" not in names[0]):
+            return
+
         try:
             entryview = page.get_entry_view()
 
@@ -315,7 +339,14 @@ class AltToolbarBase(GObject.Object):
             # some pages dont have the method to call!
             return
 
-        treeview = entryview.get_child()
+        try:
+            treeview = entryview.get_child()
+        except:
+            treeview = self.find(entryview, 'GtkTreeView', 'by_name')
+            # in RB v3.4.3 an RBEntryView doesnt have a child property...
+            # plus the GtkTreeview is now hidden inside two further
+            # containers - so we grab the tree view the hard-way of searching
+            # for the Object Type
 
         def move_col(*args):
             cols = treeview.get_columns()
@@ -1388,7 +1419,8 @@ class AltToolbarHeaderBar(AltToolbarShared):
         # hide status bar
         action = self.plugin.appshell.lookup_action('', 'statusbar-visible',
                                                     'win')
-        action.set_active(True)
+        if action:
+            action.set_active(True)
 
     def search_button_toggled(self, search_button):
         print("search_button_toggled")
@@ -1558,15 +1590,15 @@ class AltToolbarHeaderBar(AltToolbarShared):
         menu = self.shell.props.application.get_shared_menu('app-menu')
         menu_button.set_menu_model(menu)
         self._end_box_controls.add(menu_button)
-        menu.remove(3)  # help about quit
+        #menu.remove(3)  # help about quit
 
-        cl.switch_locale(cl.Locale.RB)
-        appmenu = Gio.Menu.new()
-        appmenu.append(_("_Help"), "app.help")
-        appmenu.append(_("_About"), "app.about")
-        appmenu.append(_("_Quit"), "app.quit")
-        app = self.shell.props.application
-        app.set_app_menu(appmenu)
+        #cl.switch_locale(cl.Locale.RB)
+        #appmenu = Gio.Menu.new()
+        #appmenu.append(_("_Help"), "app.help")
+        #appmenu.append(_("_About"), "app.about")
+        #appmenu.append(_("_Quit"), "app.quit")
+        #app = self.shell.props.application
+        #app.set_app_menu(appmenu)
 
         self.headerbar.pack_end(self._end_box_controls)
         self.headerbar.show_all()
